==> adsprod-facade-2.7.9-sources.jar: com/bxm/adsprod/facade/award/FetchAwardDto.java <==
package com.bxm.adsprod.facade.award;

import java.io.Serializable;

/**
 * 中奖回调数据传输对象
 *
 * @ClassName FetchAwardDto
 * @CopyRright (c) 2018-bxm：杭州微财网络科技有限公司
 * @Author kk.xie
 * @Date 2018/7/25 10:46
 * @Version 1.0
 * @Modifier kk.xie
 * @Modify Date 2018/7/25 10:46
 **/
public class FetchAwardDto implements Serializable{

    private static final long serialVersionUID = 2160802813065417710L;
    /**
     * 唯一单号
     */
    private String ordernum;

    /**
     * 状态 0 : 待领取 1：已发放 2： 已放弃
     */
    private Integer state;

    /**
     * 用户名
     */
    private String username;

    /**
     * 电话
     */
    private String phone;

    /**
     * 地址
     */
    private String useraddress;

    public String getOrdernum() {
        return ordernum;
    }

    public void setOrdernum(String ordernum) {
        this.ordernum = ordernum;
    }

    public Integer getState() {
        return state;
    }

    public void setState(Integer state) {
        this.state = state;
    }

    public String getUsername() {
        return username;
    }

    public void setUsername(String username) {
        this.username = username;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getUseraddress() {
        return useraddress;
    }

    public void setUseraddress(String useraddress) {
        this.useraddress = useraddress;
    }

    @Override
    public String toString() {
        return "FetchAwardDto{" +
                "ordernum='" + ordernum + '\'' +
                ", state=" + state +
                ", username='" + username + '\'' +
                ", phone='" + phone + '\'' +
                ", useraddress='" + useraddress + '\'' +
                '}';
    }
}

==> adsprod-facade-3.3.15.15-sources.jar: com/bxm/adsprod/facade/award/FetchAwardDto.java <==
package com.bxm.adsprod.facade.award;

import java.io.Serializable;

/**
 * 中奖回调数据传输对象
 *
 * @ClassName FetchAwardDto
 * @CopyRright (c) 2018-bxm：杭州微财网络科技有限公司
 * @Author kk.xie
 * @Date 2018/7/25 10:46
 * @Version 1.0
 * @Modifier kk.xie
 * @Modify Date 2018/7/25 10:46
 **/
public class FetchAwardDto implements Serializable{

    private static final long serialVersionUID = 2160802813065417710L;
    /**
     * 唯一单号
     */
    private String ordernum;

    /**
     * 状态 0 : 待领取 1：已发放 2： 已放弃
     */
    private Integer state;

    /**
     * 用户名
     */
    private String username;

    /**
     * 电话
     */
    private String phone;

    /**
     * 地址
     */
    private String useraddress;

    /**
     * 支付宝账号
     */
    private String alipayAccount;

    public String getOrdernum() {
        return ordernum;
    }

    public void setOrdernum(String ordernum) {
        this.ordernum = ordernum;
    }

    public Integer getState() {
        return state;
    }

    public void setState(Integer state) {
        this.state = state;
    }

    public String getUsername() {
        return username;
    }

    public void setUsername(String username) {
        this.username = username;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getUseraddress() {
        return useraddress;
    }

    public void setUseraddress(String useraddress) {
        this.useraddress = useraddress;
    }

    public String getAlipayAccount() {
        return alipayAccount;
    }

    public void setAlipayAccount(String alipayAccount) {
        this.alipayAccount = alipayAccount;
    }

    @Override
    public String toString() {
        return "FetchAwardDto{" +
                "ordernum='" + ordernum + '\'' +
                ", state=" + state +
                ", username='" + username + '\'' +
                ", phone='" + phone + '\'' +
                ", useraddress='" + useraddress + '\'' +
                '}';
    }
}
